==> mingw-w64-arrow-14.0.2-1.src.tar.zst: apache-arrow-14.0.2/csharp/src/Apache.Arrow/Types/TimeType.cs <==
﻿// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.


namespace Apache.Arrow.Types
{
    public enum TimeUnit
    {
        Second,
        Millisecond,
        Microsecond,
        Nanosecond
    }

    public abstract class TimeType: FixedWidthType
    {
        public static readonly Time32Type Second = new Time32Type(TimeUnit.Second);
        public static readonly Time32Type Millisecond = new Time32Type(TimeUnit.Millisecond);
        public static readonly Time64Type Microsecond = new Time64Type(TimeUnit.Microsecond);
        public static readonly Time64Type Nanosecond = new Time64Type(TimeUnit.Nanosecond);
        private static readonly TimeType[] _types = new TimeType[] { Second, Millisecond, Microsecond, Nanosecond };

        public TimeUnit Unit { get; }

        protected TimeType(TimeUnit unit)
        {
            Unit = unit;
        }

        public static TimeType FromTimeUnit(TimeUnit unit)
        {
            return _types[(int)unit];
        }
    }
}

==> mingw-w64-arrow-18.1.0-3.src.tar.zst: apache-arrow-18.1.0/csharp/src/Apache.Arrow/Types/TimeType.cs <==
﻿// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

namespace Apache.Arrow.Types
{
    public abstract class TimeType : TimeBasedType
    {
        public static readonly Time32Type Second = new Time32Type(TimeUnit.Second);
        public static readonly Time32Type Millisecond = new Time32Type(TimeUnit.Millisecond);
        public static readonly Time64Type Microsecond = new Time64Type(TimeUnit.Microsecond);
        public static readonly Time64Type Nanosecond = new Time64Type(TimeUnit.Nanosecond);
        private static readonly TimeType[] _types = new TimeType[] { Second, Millisecond, Microsecond, Nanosecond };

        protected TimeType(TimeUnit unit)
            : base(unit)
        {
        }

        public static TimeType FromTimeUnit(TimeUnit unit)
        {
            return _types[(int)unit];
        }
    }
}
